==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/SignalMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.InterfaceSignalSet;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceSignalSetImpl;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SignalMessage;
import io.ciera.tool.sql.ooaofooa.message.SignalMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.AsynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class SignalMessageSetImpl extends InstanceSet<SignalMessageSet,SignalMessage> implements SignalMessageSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( SignalMessage signalmessage : this ) signalmessage.setId( ref_Id );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( SignalMessage signalmessage : this ) signalmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public AsynchronousMessageSet R1019_is_a_AsynchronousMessage() throws XtumlException {
        AsynchronousMessageSet asynchronousmessageset = new AsynchronousMessageSetImpl();
        for ( SignalMessage signalmessage : this ) asynchronousmessageset.add( signalmessage.R1019_is_a_AsynchronousMessage() );
        return asynchronousmessageset;
    }
    @Override
    public InterfaceSignalSet R1021_sends_InterfaceSignal() throws XtumlException {
        InterfaceSignalSet interfacesignalset = new InterfaceSignalSetImpl();
        for ( SignalMessage signalmessage : this ) interfacesignalset.add( signalmessage.R1021_sends_InterfaceSignal() );
        return interfacesignalset;
    }


    @Override
    public SignalMessage nullElement() {
        return SignalMessageImpl.EMPTY_SIGNALMESSAGE;
    }

    @Override
    public SignalMessageSet emptySet() {
      return new SignalMessageSetImpl();
    }

    @Override
    public SignalMessageSet value() {
        return this;
    }

    @Override
    public List<SignalMessage> elements() {
        return Arrays.asList(toArray(new SignalMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/SignalMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.InterfaceSignalSet;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceSignalSetImpl;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SignalMessage;
import io.ciera.tool.sql.ooaofooa.message.SignalMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.AsynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SignalMessageSetImpl extends InstanceSet<SignalMessageSet,SignalMessage> implements SignalMessageSet {

    public SignalMessageSetImpl() {
    }

    public SignalMessageSetImpl(Comparator<? super SignalMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( SignalMessage signalmessage : this ) signalmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( SignalMessage signalmessage : this ) signalmessage.setId( ref_Id );
    }


    // selections
    @Override
    public AsynchronousMessageSet R1019_is_a_AsynchronousMessage() throws XtumlException {
        AsynchronousMessageSet asynchronousmessageset = new AsynchronousMessageSetImpl();
        for ( SignalMessage signalmessage : this ) asynchronousmessageset.add( signalmessage.R1019_is_a_AsynchronousMessage() );
        return asynchronousmessageset;
    }
    @Override
    public InterfaceSignalSet R1021_sends_InterfaceSignal() throws XtumlException {
        InterfaceSignalSet interfacesignalset = new InterfaceSignalSetImpl();
        for ( SignalMessage signalmessage : this ) interfacesignalset.add( signalmessage.R1021_sends_InterfaceSignal() );
        return interfacesignalset;
    }


    @Override
    public SignalMessage nullElement() {
        return SignalMessageImpl.EMPTY_SIGNALMESSAGE;
    }

    @Override
    public SignalMessageSet emptySet() {
      return new SignalMessageSetImpl();
    }

    @Override
    public SignalMessageSet emptySet(Comparator<? super SignalMessage> comp) {
      return new SignalMessageSetImpl(comp);
    }

    @Override
    public SignalMessageSet value() {
        return this;
    }

    @Override
    public List<SignalMessage> elements() {
        return Arrays.asList(toArray(new SignalMessage[0]));
    }

}
